import pandas as pd
import matplotlib.pyplot as plt
from scipy.integrate import simps
import time
import numpy as np

# Leser inn Excel-filene
excel_file1 = 'ferdigkalibrert.xlsx'   #legge inn excell fra Modellen 
excel_file2 = 'filtered_vannforing_data_Sildre.xlsx'          #legge inn excell fra Sildre 
df1 = pd.read_excel(excel_file1, sheet_name='juli')  #
df2 = pd.read_excel(excel_file2, sheet_name='Sheet1')

# Konverterer tidssøyler til datetime og justerer tidspunkt
df1['Time'] = pd.to_datetime(df1['Time'])
df2['Tidspunkt'] = pd.to_datetime(df2['Tidspunkt'])
df2['Tidspunkt'] += pd.Timedelta(hours=1)  # Legger til en time til 'tidspunkt' # Sildre har vinter tid og sommertid. 

# Definerer start- og sluttdato for ønsket tidsintervall
start_date = '2023-07-01 01:00:00'
end_date = '2023-07-31 01:00:00'

# Filtrer DataFrames basert på det tilpassede tidsintervallet
df1_custom = df1[(df1['Time'] >= start_date) & (df1['Time'] <= end_date)]
df2_custom = df2[(df2['Tidspunkt'] >= start_date) & (df2['Tidspunkt'] <= end_date)]

# Synkroniserer df1_custom og df2_custom basert på tidsstempler
df1_custom = df1_custom.rename(columns={'Time': 'Tidspunkt'})
merged_df = pd.merge_asof(df1_custom.sort_values('Tidspunkt'), df2_custom.sort_values('Tidspunkt'), on='Tidspunkt', direction='nearest')

# Beregner punktvis differanse
diff1 = merged_df['Vannforing (kubemeter/s)'] - merged_df['Link Discharge 22183-86, 16.14[meter^3/sec]']
time1 = df1_custom['Tidspunkt']


def total_vannføring():
    # Konverterer tidspunkt til sekunder siden starten av perioden for nøyaktig tidsdifferanse
    tid_df1 = (df1_custom['Tidspunkt'] - pd.Timestamp(start_date)).dt.total_seconds()
    tid_df2 = (df2_custom['Tidspunkt'] - pd.Timestamp(start_date)).dt.total_seconds()

    # Beregner total vannføring for modellen og Sildre
    # Bruker Simpson's regel for integrasjon
    total_vannforing_modell = simps(df1_custom['Link Discharge 22183-86, 16.14[meter^3/sec]'], tid_df1)
    total_vannforing_sildre = simps(df2_custom['Vannforing (kubemeter/s)'], tid_df2)

    return total_vannforing_modell, total_vannforing_sildre

def maks_vannføring():
    # Finner maksverdi og tilhørende tidspunkt for modellens data
    peak_modell_verdi = max(df1_custom['Link Discharge 22183-86, 16.14[meter^3/sec]'])
    peak_modell_tid = df1_custom.loc[df1_custom['Link Discharge 22183-86, 16.14[meter^3/sec]'] == peak_modell_verdi, 'Tidspunkt'].iloc[0]

    # Finner maksverdi og tilhørende tidspunkt for Sildre's data
    peak_sildre_verdi = max(df2_custom['Vannforing (kubemeter/s)'])
    peak_sildre_tid = df2_custom.loc[df2_custom['Vannforing (kubemeter/s)'] == peak_sildre_verdi, 'Tidspunkt'].iloc[0]

    return round(peak_modell_verdi,3), round(peak_sildre_verdi,3),

# Kall funksjonen og vis resultatene
modell_vannforing, sildre_vannforing = total_vannføring()
print(f"Total vannføring fra modellen: {round(modell_vannforing,3)} m^3")
print(f"Total vannføring fra Sildre: {round(sildre_vannforing,3)} m^3")
print(f"Peak vannføring fra modell: {maks_vannføring()[0]} m^3/s")
print(f"Peak vannføring fra Sildre: {maks_vannføring()[1]} m^3/s")
def gjennomsnittvannføring():
    sum1 = 0  # Modell 
    sum2 = 0  #Sildre
    for i in range (len(df1_custom['Link Discharge 22183-86, 16.14[meter^3/sec]'])):
        sum1 += df1_custom['Link Discharge 22183-86, 16.14[meter^3/sec]'][i]
    for j in range (len(df2_custom['Vannforing (kubemeter/s)'])):
        sum2 += df2_custom['Vannforing (kubemeter/s)'][j]
    
    snitt_sildre = round(sum2 / len(df2_custom['Vannforing (kubemeter/s)']),3)
    snitt_modell = round(sum1 / len(df1_custom['Link Discharge 22183-86, 16.14[meter^3/sec]']),3)
    return snitt_modell,snitt_sildre

print(diff1)

'''
# Plotter dataene
plt.figure(figsize=(15, 7), dpi=96)
plt.plot(merged_df['Tidspunkt'], merged_df['Link Discharge 22183-86, 16.14[meter^3/sec]'], linestyle='-', linewidth=1, label='Modell')
plt.plot(merged_df['Tidspunkt'], merged_df['Vannforing (kubemeter/s)'], linestyle='-', linewidth=1, label='Observert (Sildre)')
plt.title("Water Discharge Data Comparison - m³/s")
plt.xlabel("Date")
plt.ylabel("Water Discharge (m³/s)")
plt.xticks(rotation=45)
plt.grid(True)
plt.legend()
plt.tight_layout()
plt.show()
'''
plt.figure(figsize=(15, 7), dpi=96)
plt.plot(time1,diff1)
plt.title("Differansen mellom vannføringene - m³/s")
plt.xlabel("Date")
plt.ylabel("Water Discharge (m³/s)")
plt.xticks(rotation=45)
plt.grid(True)
plt.legend()
plt.tight_layout()
plt.show()
'''
# Definerer time1 fra den synkroniserte DataFrame (merged_df)
time1 = merged_df['tidspunkt']

# Oppretter en ny DataFrame med tidspunkt og differansen
excel_df = pd.DataFrame({
    'Tidspunkt': time1,
    'Differanse': diff1
})

# Lagrer DataFrame-en til en Excel-fil
excel_filnavn = 'differanse_data.xlsx'
excel_df.to_excel(excel_filnavn, index=False)

excel_filnavn

'''