import pandas as pd
import matplotlib.pyplot as plt

# Leser inn Excel-filene
excel_file = 'sammensattmodell.xlsx'  # Legger inn Excel fra Modellen
excel_file1 = 'Data2021.xlsx'
DWF = pd.read_excel(excel_file, sheet_name='Tørrvær')  # Tørrvær
RainJuli = pd.read_excel(excel_file, sheet_name='RegnJuli')  
RainOctober = pd.read_excel(excel_file, sheet_name='RegnOktober')
Measured  = pd.read_excel(excel_file1, sheet_name='Vannføring')

# Konverterer tidssøyler til datetime
DWF['Time'] = pd.to_datetime(DWF['Time'])
RainJuli['Time'] = pd.to_datetime(RainJuli['Time'])
RainOctober['Time'] = pd.to_datetime(RainOctober['Time'])
Measured['Time'] = pd.to_datetime(Measured['Time'])

# Definerer start- og sluttdato for ønsket tidsintervall
start_date = '2021-10-01 00:00:00'
end_date = '2021-10-06 00:00:00'

# Filtrer DataFrames basert på det tilpassede tidsintervallet
DWF_custom = DWF[(DWF['Time'] >= start_date) & (DWF['Time'] <= end_date)]
RainJuli_custom = RainJuli[(RainJuli['Time'] >= start_date) & (RainJuli['Time'] <= end_date)]
RainOctober_custom = RainOctober[(RainOctober['Time'] >= start_date) & (RainOctober['Time'] <= end_date)]
Measured_custom = Measured[(Measured['Time'] >= start_date) & (Measured['Time'] <= end_date)]

# Beregner periodelengde i dager
periode_lengde = (pd.to_datetime(end_date) - pd.to_datetime(start_date)).days

# Beregner gjennomsnittlig flow
average_flow = RainOctober_custom['Link Discharge 25733-312, 15.55[liter/sec]'].mean()
average_flow_measured = Measured_custom['Discharge_A [l/s]'].mean()
average_flow_teori = 10.20

# Utdata
print(f"Start dato : {start_date}")
print(f"Slut dato : {end_date}")
print(f"Periode lengde : {periode_lengde} dager")
print(f"Peak flow: {RainOctober_custom['Link Discharge 25733-312, 15.55[liter/sec]'].max()} l/s ")
print(f"Min flow : {RainOctober_custom['Link Discharge 25733-312, 15.55[liter/sec]'].min()} l/s")
print(f"Gjennomsnitt flow :{average_flow} l/s ")

# Plotting
plt.figure(figsize=(15, 7), dpi=96)
plt.plot(RainOctober_custom['Time'], RainOctober_custom['Link Discharge 25733-312, 15.55[liter/sec]'], linestyle='-', linewidth=1, label='Model')
plt.plot(Measured_custom['Time'], Measured_custom['Discharge_A [l/s]'], linestyle='-', linewidth=1, label='Measured')
plt.axhline(y=average_flow, color='r', linestyle='--', label=f'Average Flow Model: {average_flow:.2f} l/s', linewidth=2)
plt.axhline(y=average_flow_measured, color='g', linestyle='--', label=f'Average Flow Measured: {average_flow_measured:.2f} l/s',linewidth=2)
plt.axhline(y=average_flow_teori, color='b', linestyle='--', label=f'Average Flow Teori: {average_flow_teori:.2f} l/s',linewidth=2)
plt.title("Vannføring i Målepunktet")
plt.xlabel("Date")
plt.ylabel("liter/sec")
plt.xticks(rotation=45)
plt.grid(True)
plt.legend()
plt.tight_layout()
plt.show()
